@@ -1,29 +1,26 @@
-# -*- coding: utf-8 -*-
-
 """
-cookiecutter.replay
+cookiecutter.replay.
+
 -------------------
 """
-
-from __future__ import unicode_literals
-
 import json
 import os
-from past.builtins import basestring
 
-from .utils import make_sure_path_exists
+from cookiecutter.utils import make_sure_path_exists
 
 
 def get_file_name(replay_dir, template_name):
-    file_name = '{}.json'.format(template_name)
+    """Get the name of file."""
+    suffix = '.json' if not template_name.endswith('.json') else ''
+    file_name = f'{template_name}{suffix}'
     return os.path.join(replay_dir, file_name)
 
 
-def dump(replay_dir, template_name, context):
-    if not make_sure_path_exists(replay_dir):
-        raise IOError('Unable to create replay dir at {}'.format(replay_dir))
+def dump(replay_dir: "os.PathLike[str]", template_name: str, context: dict):
+    """Write json data to file."""
+    make_sure_path_exists(replay_dir)
 
-    if not isinstance(template_name, basestring):
+    if not isinstance(template_name, str):
         raise TypeError('Template name is required to be of type str')
 
     if not isinstance(context, dict):
@@ -35,16 +32,17 @@ def dump(replay_dir, template_name, context):
     replay_file = get_file_name(replay_dir, template_name)
 
     with open(replay_file, 'w') as outfile:
-        json.dump(context, outfile)
+        json.dump(context, outfile, indent=2)
 
 
 def load(replay_dir, template_name):
-    if not isinstance(template_name, basestring):
+    """Read json data from file."""
+    if not isinstance(template_name, str):
         raise TypeError('Template name is required to be of type str')
 
     replay_file = get_file_name(replay_dir, template_name)
 
-    with open(replay_file, 'r') as infile:
+    with open(replay_file) as infile:
         context = json.load(infile)
 
     if 'cookiecutter' not in context:
