@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
 """Provides custom extension, exposing a ``hello`` command."""
-
 from jinja2 import nodes
 from jinja2.ext import Extension
 
@@ -9,15 +6,15 @@ from jinja2.ext import Extension
 class HelloExtension(Extension):
     """Simple jinja2 extension for cookiecutter test purposes."""
 
-    tags = set(['hello'])
+    tags = {'hello'}
 
     def __init__(self, environment):
         """Hello Extension Constructor."""
-        super(HelloExtension, self).__init__(environment)
+        super().__init__(environment)
 
     def _hello(self, name):
         """Do actual tag replace when invoked by parser."""
-        return 'Hello {name}!'.format(name=name)
+        return f'Hello {name}!'
 
     def parse(self, parser):
         """Work when something match `tags` variable."""
