@@ -20,7 +20,8 @@ def remove_additional_dirs(request):
 def test_cookiecutter_local_with_input(monkeypatch):
     """Verify simple cookiecutter run results, without extra_context provided."""
     monkeypatch.setattr(
-        'cookiecutter.prompt.read_user_variable', lambda var, default: default
+        'cookiecutter.prompt.read_user_variable',
+        lambda var, default, prompts: default,
     )
     main.cookiecutter('tests/fake-repo-pre/', no_input=False)
     assert os.path.isdir('tests/fake-repo-pre/{{cookiecutter.repo_name}}')
@@ -34,7 +35,8 @@ def test_cookiecutter_local_with_input(monkeypatch):
 def test_cookiecutter_input_extra_context(monkeypatch):
     """Verify simple cookiecutter run results, with extra_context provided."""
     monkeypatch.setattr(
-        'cookiecutter.prompt.read_user_variable', lambda var, default: default
+        'cookiecutter.prompt.read_user_variable',
+        lambda var, default, prompts: default,
     )
     main.cookiecutter(
         'tests/fake-repo-pre',
