@@ -171,18 +171,19 @@ def test_apply_overwrites_does_not_modify_choices_for_invalid_overwrite():
         )
     }
 
-    generated_context = generate.generate_context(
-        context_file='tests/test-generate-context/choices_template.json',
-        default_context={
-            'not_in_template': 'foobar',
-            'project_name': 'Kivy Project',
-            'orientation': 'foobar',
-        },
-        extra_context={
-            'also_not_in_template': 'foobar2',
-            'github_username': 'hackebrot',
-        },
-    )
+    with pytest.warns(UserWarning, match="Invalid default received"):
+        generated_context = generate.generate_context(
+            context_file='tests/test-generate-context/choices_template.json',
+            default_context={
+                'not_in_template': 'foobar',
+                'project_name': 'Kivy Project',
+                'orientation': 'foobar',
+            },
+            extra_context={
+                'also_not_in_template': 'foobar2',
+                'github_username': 'hackebrot',
+            },
+        )
 
     assert generated_context == expected_context
 
@@ -202,3 +203,45 @@ def test_apply_overwrites_sets_default_for_choice_variable(template_context):
     )
 
     assert template_context['orientation'] == ['landscape', 'all', 'portrait']
+
+
+def test_apply_overwrites_in_nested_dict():
+    """Verify nested dict in default content settings are correctly replaced."""
+    expected_context = {
+        'nested_dict': OrderedDict(
+            [
+                ('full_name', 'Raphael Pierzina'),
+                ('github_username', 'hackebrot'),
+                (
+                    'project',
+                    OrderedDict(
+                        [
+                            ('name', 'My Kivy Project'),
+                            ('description', 'My Kivy Project'),
+                            ('repo_name', '{{cookiecutter.project_name|lower}}'),
+                            ('orientation', ["all", "landscape", "portrait"]),
+                        ]
+                    ),
+                ),
+            ]
+        )
+    }
+
+    generated_context = generate.generate_context(
+        context_file='tests/test-generate-context/nested_dict.json',
+        default_context={
+            'not_in_template': 'foobar',
+            'project': {
+                'description': 'My Kivy Project',
+            },
+        },
+        extra_context={
+            'also_not_in_template': 'foobar2',
+            'github_username': 'hackebrot',
+            'project': {
+                'name': 'My Kivy Project',
+            },
+        },
+    )
+
+    assert generated_context == expected_context
